@@ -102,6 +102,9 @@ class gram():
     def __lt__(self, other):
         return gram(f"({self.value})/({other.rule()})")
 
+    def __div__(self, other):
+        return gram(f"({self.value})/({other.rule()})")
+
     def __gt__(self, other):
         return gram(f"({self.value})\\({other.rule()})")
 
@@ -297,3 +300,4 @@ acc = gram('acc')
 inst = gram('inst')
 loc = gram('loc')
 postp = gram('postp')
+n = gram('n')
